summaryrefslogtreecommitdiffstats
path: root/core/java/android/app
diff options
context:
space:
mode:
authorDaniel Sandler <dsandler@android.com>2010-02-04 15:58:18 -0800
committerAndroid (Google) Code Review <android-gerrit@google.com>2010-02-04 15:58:18 -0800
commit64226a49b75b44da56740a21b38ce6cc710796d8 (patch)
treecbfc7f880fa7b8b98daadbbc0ea2be2095324ebb /core/java/android/app
parent214ea34bcab790f19c4302ab2629b3b9de58e2c1 (diff)
parent91e1d0cddaaec5e077ca689744463901f9d5d580 (diff)
downloadframeworks_base-64226a49b75b44da56740a21b38ce6cc710796d8.zip
frameworks_base-64226a49b75b44da56740a21b38ce6cc710796d8.tar.gz
frameworks_base-64226a49b75b44da56740a21b38ce6cc710796d8.tar.bz2
Merge "Add support in StatusBarManager for disabling ticker text."
Diffstat (limited to 'core/java/android/app')
-rw-r--r--core/java/android/app/StatusBarManager.java10
1 files changed, 8 insertions, 2 deletions
diff --git a/core/java/android/app/StatusBarManager.java b/core/java/android/app/StatusBarManager.java
index 51d7393..72ec616 100644
--- a/core/java/android/app/StatusBarManager.java
+++ b/core/java/android/app/StatusBarManager.java
@@ -31,12 +31,12 @@ import android.os.ServiceManager;
public class StatusBarManager {
/**
* Flag for {@link #disable} to make the status bar not expandable. Unless you also
* set {@link #DISABLE_NOTIFICATIONS}, new notifications will continue to show.
*/
public static final int DISABLE_EXPAND = 0x00000001;
/**
- * Flag for {@link #disable} to hide notification icons and ticker text.
+ * Flag for {@link #disable} to hide notification icons and scrolling ticker text.
*/
public static final int DISABLE_NOTIFICATION_ICONS = 0x00000002;
@@ -47,6 +47,12 @@ public class StatusBarManager {
public static final int DISABLE_NOTIFICATION_ALERTS = 0x00000004;
/**
+ * Flag for {@link #disable} to hide only the scrolling ticker. Note that
+ * {@link #DISABLE_NOTIFICATION_ICONS} implies {@link #DISABLE_NOTIFICATION_TICKER}.
+ */
+ public static final int DISABLE_NOTIFICATION_TICKER = 0x00000008;
+
+ /**
* Re-enable all of the status bar features that you've disabled.
*/
public static final int DISABLE_NONE = 0x00000000;
@@ -31,12 +31,12 @@ import android.os.ServiceManager;
/**
* Flag for {@link #disable} to make the status bar not expandable. Unless you also
- * set {@link #DISABLE_NOTIFICATIONS}, new notifications will continue to show.
+ * set {@link #DISABLE_NOTIFICATION_ICONS}, new notifications will continue to show.
*/
public static final int DISABLE_EXPAND = 0x00000001;